@@ -36,7 +36,7 @@ try:
     import pyfftw
     pyfftw_available = True
 except ImportError:
-    print("WARNING: pyfftw not available, will use numpy")
+    log.info("pyfftw not available, will use numpy")
     pyfftw = ModuleNotAvailable(message="pyfftw not available")
     pyfftw_available = False
 
@@ -83,6 +83,8 @@ class ContextCpu(XContext):
 
     """
 
+    nplike_array_type = np.ndarray
+
     def __init__(self, omp_num_threads=0):
         super().__init__()
         self.omp_num_threads = omp_num_threads
